DRV2605 Haptic Driver
=====================

`Build Status <https://travis-ci.com/pimoroni/drv2605-python>`__
`Coverage
Status <https://coveralls.io/github/pimoroni/drv2605-python?branch=master>`__
`PyPi Package <https://pypi.python.org/pypi/drv2605>`__ `Python
Versions <https://pypi.python.org/pypi/drv2605>`__

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install drv2605``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/drv2605-python``
-  ``cd drv2605-python``
-  ``sudo ./install.sh``

Vibration Patterns
==================

The DRV2605 has a library of built-in vibration patterns great for
haptic feedback, notifications and more. For the complete list see:

http://www.ti.com/document-viewer/DRV2605/datasheet/waveform-library-effects-list-slos854718
